# Info-UNASUS

Modelo para desenvolvimento de infográfico.

# Sumário

- [Estrutura dos arquivos](#estrutura-dos-arquivos)
- [O que é React?](#o-que-e-react)
- [O que são Hooks?](#o-que-sao-hooks)
- [Como utilizar o sistema de Rotas](#como-utilizar-sistema-de-rotas)
- [Como organizar uma página do infográfico](#como-organizar-uma-pagina-do-infografico)
  - [Estrutura do arquivo index.js](#estrutura-do-arquivo-index.js)
  - [Estrutura do arquivo styles.js](#estrutura-do-arquivo-styles.js)
- [Como estilizar no material UI](#como-estilizar-no-material-ui)
  - [Como utilizar makeStyles](#como-utilizar-makestyles)
  - [Como utilizar o styled-components no Material UI](#como-utilizar-o-styled-components-no-material-ui)
- [Como utilizar o tema](#como-utilizar-o-tema)
  - [Usando tema no makeStyles](#usando-tema-no-makestyles)
  - [Usando tema no Styled-components](#usando-tema-no-styled-components)
- [Como utilizar os componentes presentes no infográfico](#como-utilizar-os-componentes-presentes-no-infografico)
  - [Accordion](#accordion)
  - [Activities](#activities)
  - [AnimatedList](#animatedlist)
  - [Attention](#attention)
  - [ContourBox](#contourbox)
  - [Dialog](#dialog)
  - [ShadedBox](#shaded-box)
  - [Simple](#simple)
  - [Slide](#slide)
  - [Zoom](#zoom)

# Estrutura dos arquivos <a name="estrutura-dos-arquivos"></a>

```
src/
|
|-- components/
|     |-- core/
|-- pages/
      |-- p1/
          |-- index.js
          |-- styles.js
|-- store
|-- config.js
|-- index.js
|-- routes.js
|-- theme.js
|-- .gitignore
|-- package.json
|-- README.md
```

# O que é React? <a name="o-que-e-react"></a>

Sobre o funcionamento do React segue um conjunto de links explicando seu funcionamento.

[Introdução ao React](https://pt-br.reactjs.org/docs/getting-started.html)

[Pensando do jeito React](https://pt-br.reactjs.org/docs/thinking-in-react.html)

[Iniciando no React - Diego Fernandes](https://www.youtube.com/watch?v=7A4UQGrFU9Q)

# O que são Hooks? <a name="o-que-sao-hooks"></a>

Para o estudo sobre os hooks, segue links de estudos:

[Introdução aos Hooks - React](https://pt-br.reactjs.org/docs/hooks-intro.html)

[React Hooks na prática - Diego Fernandes](https://www.youtube.com/watch?v=6WB16wZS61c)

# Como utilizar o sistema de Rotas <a name="como-utilizar-sistema-de-rotas"></a>

O sistema de rotas é feito através do react-router-dom onde é utilizado o lazy e o Suspense do React para gerar o lazy loading. Para adicionar uma rota primeiro o componente precisa ser importado e e ser passado como parâmetro para a função lazy como uma arrow function. Em seguida no HTML da página é utilizado o Route para definir o caminho da url será utilizado e qual componente será exibido quando a rota for acessada.

```
import React, { Suspense, lazy} from 'react';
import {HashRouter, Switch, Route} from 'react-router-dom';

const p1 = lazy(() => import('./pages/p1'))
const p1_creditos = lazy(() => import('./pages/p1_creditos'))
const p2 = lazy(() => import('./pages/p2'))

export default () => (
    <HashRouter>
        <Suspense fallback={<div></div>}>
            <Switch>
                <Route exact path="/" component={p1} />
                <Route path="/creditos" component={p1_creditos} />
                <Route path="/p2" component={p2} />
            </Switch>
        </Suspense>
    </HashRouter>
);
```

# Como organizar uma página do infográfico <a name="como-organizar-uma-pagina-do-infografico"></a>

Cada página é formada por uma pasta na qual contém dois arquivos um onde é o index.js e o outro onde é o styles.js sendo utilizado para guardar a estilização da página.

## Estrutura do arquivo index.js <a name="estrutura-do-arquivo-index.js"></a>

```
import React from 'react'
import { Typography, Box } from '@material-ui/core'
import useStyles from './styles'
export default function () {
    const classes = useStyles()

    return (
        <>
            <Box overflow="auto" width="1" height="1">
                <Typography variant="h1" className={classes.text}>
                    H1
                </Typography>
            </Box>
        </>
    )
}
```

## Estrutura do arquivo styles.js <a name="estrutura-do-arquivo-styles.js"></a>

```
import { makeStyles } from '@material-ui/core/styles';

export default makeStyles(theme => ({
  text: {
    color: "#F0F0F0"
  },
  panels: {
    height: "65%",
    maxHeight: "200px"
  }
}));
```

# Como estilizar no material UI <a name="como-estilizar-no-material-ui"></a>

## Como utilizar makeStyles <a name="como-utilizar-makestyles"></a>

O material UI disponibiliza o Hook API para estilizar os componentes.

[MaterialUI-Estilos](https://material-ui.com/pt/styles/basics/#primeiros-passos)

## Como utilizar o styled-components no Material UI <a name="como-utilizar-o-styled-components-no-material-ui"></a>

Os componentes do material UI também podem ser customizado por meio do styled-components. E na documentação do Material UI sobre a interoperabilidade dos estilos ele menciona o uso do styled-components

[Interoperabilidade da Biblioteca de Estilo-Styled Components](https://material-ui.com/pt/guides/interoperability/#styled-components)

# Como utilizar o tema <a name="como-utilizar-o-tema"></a>

O uso de tema facilita a estilização, pois define cores padrões e tamanho de fonte que será utilizada por todo o projeto.

## Usando tema no makeStyles <a name="usando-tema-no-makestyles"></a>

```
const styles = makeStyles(theme => ({
  headerTitle: {
    backgroundColor: theme.palette.primary.main,
    color: "#FFF"
  }
}));
```

## Usando tema no Styled-components <a name="usando-tema-no-styled-components"></a>

```
import styled from 'styled-components'
import Grid from '@material-ui/core/Grid'

export const Container = styled(Grid)`
    width: 100%;
    height: 100vh !important;

    #center-container{
        height: 100%;

        background-color: ${props => props.theme.palette.background.main};
    }
`
```

# Como utilizar os componentes presentes no infográfico <a name="como-utilizar-os-componentes-presentes-no-infografico"></a>

## Accordion <a name="accordion"></a>

Importe o Accordion

```
import Accordion from "../../components/Accordion";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Accordion Material={material} />
```

O Material é uma lista de objetos que deve conter a seguinte estrutura:

```
const material = [
    {
      painel: "1",
      title: "Exemplo 1",
      content:
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum velit massa, efficitur quis erat sed, pretium egestas est.",
    },
    {
      painel: "2",
      title: "Exemplo 2",
      content:
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum velit massa, efficitur quis erat sed, pretium egestas est.",
    },
    {
      painel: "3",
      title: "Exemplo 3",
      content:
        "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vestibulum velit massa, efficitur quis erat sed, pretium egestas est. ",
    },
  ];
```

## Activities <a name="activities"></a>

Importe o Activities

```
import Activities from '../../components/Activities'
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Activities
  Key='NomedoInfo_Q1'
  Respostas={respostas}
  Alternativas={alternativas}
  Objetivo='Reconhecer os sinais e sintomas que, associados a diarreia ou vômito, indicam necessidade atendimento com urgência e/ou encaminhamento imediato.'
  numQuestao={7}
  Questao='A presença de sintomas de diarreia ou vômitos pode estar relacionada a outras condições de saúde que devem ser aferidas, a fim de avaliar necessidade de atendimento de urgência e/ou encaminhamento5. Entre os sinais e sintomas iniciais mais graves quando associados a diarreia e vômito, indicativos da necessidade de atendimento de urgência e/ou encaminhamento, está:'
/>
```

- Key: chave da questao - irá diferenciá-la das outras questões. Aconselho seguir o modelo utilizado no exemplo;
- Objetivo: texto referente ao Objetivo Educacional;
- numQuestao: número referente a questão;
- Questao: enunciado da questão.

Respostas: são as respostas que aparecerá na mensagem de correção. É uma lista de objetos que deve conter a seguinte estrutura:

```
const respostas = [
    {
      alternativa: 'a',
      validacao: 'incorreta',
      resposta:
        'a) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    },
    {
      alternativa: 'b',
      validacao: 'incorreta',
      resposta:
        'b) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    },
    {
      alternativa: 'c',
      validacao: 'correta',
      resposta:
        'c) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    },
    {
      alternativa: 'd',
      validacao: 'incorreta',
      resposta:
        'd) Vivamus suscipit tortor eget felis porttitor volutpat. Vivamus suscipit tortor eget felis porttitor volutpat.'
    }
  ]
```

Alternativas: são as alternativas de escolha do aluno. É uma lista de objetos que deve conter a seguinte estrutura:

```
const alternativas = [
    { alternativa: 'a', texto: 'a) Vivamus suscipit tortor eget felis porttitor volutpat.' },
    { alternativa: 'b', texto: 'b) Vivamus suscipit tortor eget felis porttitor volutpat.' },
    { alternativa: 'c', texto: 'c) Vivamus suscipit tortor eget felis porttitor volutpat.' },
    { alternativa: 'd', texto: 'd) Vivamus suscipit tortor eget felis porttitor volutpat.' }
  ]
```

## AnimatedList <a name="animatedlist"></a>

Importe o AnimatedList

```
import AnimatedList from '../../components/AnimatedList';
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<AnimatedList
  List={list}
  paresColor='#fff'
  paresBackgroundColor='#00B5B1'
  imparesColor='#fff'
  imparesBackgroundColor='#00CFCA'
/>
```

- paresColor: cor do texto dos elementos pares;
- paresBackgroundColor: cor do background dos elementos pares;
- imparesColor: cor do texto dos elementos impares;
- imparesBackgroundColor: cor do background dos elementos impares;

O List é uma lista de strings que deve conter a seguinte estrutura:

```
const list = [
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.',
    'Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.'
  ]
```

## Attention <a name="attention"></a>

Importe o Attention e, caso necessite, importe também a imagem do icone que ficará do lado do título:

```
import Attention from "../../components/Attention";
import important from "../../assets/icons/ATENCAO.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Attention Image={important} Title='IMPORTANTE'>
  Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.
</Attention>
```

- Image: ícone que ficará ao lado do Título;
- Title: Título do Attention;
- Color: Cor do título;
- Border: Cor da borda;
- O conteudo deverá ser colocado dentro das tags, enviado como children.

## ContourBox <a name="contourbox"></a>

Importe o ContourBox e, caso necessite, importe também a imagem do icone que ficará ao lado do texto no conteúdo:

```
import ContourBox from "../../components/ContourBox";
import image from "../../assets/images/unnamed.jpg";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<ContourBox Image={image}>
  Praesent sapien massa, convallis a pellentesque nec, egestas non nisi. Mauris blandit aliquet elit, eget tincidunt nibh pulvinar a.
</ContourBox>
```

- Image: Imagem que acompanhará o conteúdo em texto;
- Border: Cor da borda;
- Height: Controla a altura do ContourBox - padrão: auto;
- O conteudo deverá ser colocado dentro das tags, enviado como children.

## Dialog <a name="dialog"></a>

Importe o Dialog e, caso necessite, importe também a imagem do botão:

```
import Dialog from "../../components/Dialog";
import SaberMais from "../../assets/buttons/saber.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Dialog
  content={content}
  title='Exemplo de Dialog'
  image={SaberMais}
/>
```

- content: conteúdo do Dialog;
- title: título do Dialog;
- image: imagem que será usada como butão, caso exista;
- clicked: determina se o botão ja foi clicado ou não(true ou false);
- help: se utilizado, o botão do Dialog será o icone "?";
- buttonText: se utilizado, o botão sera um texto com fundo;
- colorText: cor do texto do buttonText;
- colorBackground: define a cor do background do botão.
- colorBackgroundHover: define a cor do backgroundHover do botão.

## ShadedBox <a name="shaded-box"></a>

Importe o ShadedBox e, caso necessite, importe também a imagem que acompanhará o conteúdo:

```
import ShadedBox from "../../components/ShadedBox";
import imageTest from "../../assets/images/garota.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<ShadedBox
  Content={content}
  backgroundColor='#00B5B1'
  Color='#fff'
  Image={imageTest}
  Right
/>
```

- Content: conteúdo do ShadedBox;
- Image: imagem que acompanhará o conteúdo do ShadedBox;
- Color: cor do texto do conteúdo - padrão: #000;
- backgroundColor: cor do background do conteúdo - padrão: #fff;
- right: com esta propriedade a imagem ficará a direita do conteúdo.

## Simple <a name="simple"></a>

Importe o Simple:

```
import Simple from "../../components/Simple";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Simple Content={content} borderColor='#00B5B1' Color='#00B5B1' />
```

- Content: conteúdo do Simple;
- Color: cor do texto do conteúdo;
- borderColor: cor da borda do conteúdo;

## Slide <a name="slide"></a>

Importe o Slide e as imagens que fará parte dele:

```
import Slide from "../../components/Slide";
import imagemEx from "../../assets/images/unnamed.jpg";
import imagemEx2 from "../../assets/images/unnamed2.png";
import imagemEx3 from "../../assets/images/unnamed3.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Slide Content={material} />
```

O conteúdo do Content deve ser um array de objetos com a seguinte estrutura:

```
const material = [
    {
      img: imagemEx,
      text:
        "Texto 1 Vivamus magna justo, lacinia eget consectetur sed, convallis at tellus. Vivamus suscipit tortor eget felis porttitor volutpat.",
    },
    {
      img: imagemEx2,
      text:
        "Texto 2 Vivamus magna justo, lacinia eget consectetur sed, convallis at tellus. Vivamus suscipit tortor eget felis porttitor volutpat.",
    },
    {
      img: imagemEx3,
      text:
        " Texto 3 Vivamus magna justo, lacinia eget consectetur sed, convallis at tellus. Vivamus suscipit tortor eget felis porttitor volutpat.",
    },
    { img: imagemEx3 },
    {
      text:
        " Texto 3 Vivamus magna justo, lacinia eget consectetur sed, convallis at tellus. Vivamus suscipit tortor eget felis porttitor volutpat.",
    },
  ];
```

## Zoom <a name="zoom"></a>

Importe o Zoom e a imagem:

```
import Zoom from "../../components/Zoom";
import garota from "../../assets/images/garota.png";
```

Defina-o da seguinte maneira no local onde deseja utilizá-lo:

```
<Zoom src={garota} />
```


