import React, { useRef, useState, useEffect } from 'react'
import { Typography, Box } from '@material-ui/core'
import API from '../../core/Lti/api'

import Header from '../Header'
import Footer from '../Footer'
import Dialog from '../Dialog'

import { Content, Correta, Incorreta } from './styles'
import { ListAltSharp } from '@material-ui/icons'

export default function (props) {
  const headerref = useRef(Header)

  const [btnAtivo, setBtnAtivo] = useState(0)

  const key = props.Key

  const [reply, setReply] = useState('')
  const [textoModal, setTextoModal] = useState([])

  const [status, setStatus] = useState('')

  const sendAnswers = async (answers) => {
    await API.setData(key, { resposta: answers })
    props.Respostas.map((item) => {
      if (item.alternativa === answers) {
        if (item.validacao === 'correta') {
          setStatus('Correta!')
          setTextoModal(
            <>
              <Correta>
                <Typography variant='body1' className='correta'>
                  {item.resposta}
                </Typography>
              </Correta>
            </>
          )
        } else {
          setStatus('Incorreta!')
          setTextoModal(
            <>
              <Incorreta>
                <Typography variant='body1' className='incorreta'>
                  {item.resposta}
                </Typography>
              </Incorreta>
            </>
          )
        }
      }
    })
  }

  useEffect(() => {
    const init = async () => {
      const data = await API.getData(key)
      if (data) {
        setReply(data.resposta)
      }
      return false
    }
    init()
  }, [])

  return (
    <Content btnAtivo={btnAtivo}>
      <Box className='title'>
        <Typography variant='h5'>Atividades</Typography>
      </Box>
      <Box className='content'>
        <Box className='text'>
          <Typography variant='body1' className=''>
            <strong>Objetivo Educacional</strong>: {props.Objetivo}
            {/* <p>
                Exemplo de referência<Reference num='1' onClick={() => openRef(1)}/>.
                </p> */}
          </Typography>
          <Typography variant='body1' className=''>
            <strong>Questão {props.numQuestao}</strong>: {props.Questao}
          </Typography>
        </Box>
        <Box className='alternativas'>
          {props.Alternativas.map((item, index) => {
            return (
              <Typography
                key={index}
                variant='body1'
                className={
                  reply === item.alternativa
                    ? 'alternativa alternativaEscolhida'
                    : 'alternativa alternativaNaoEscolhida'
                }
                onClick={() => [setReply(item.alternativa)]}
              >
                {item.texto}
              </Typography>
            )
          })}
        </Box>
        <Box className='boxDialog' onClick={() => [sendAnswers(reply)]}>
          <Dialog
            buttonText='enviar'
            classe='enviar'
            colorText='#fff'
            colorBackground='#00B5B1'
            colorBackgroundHover='#317C7C'
            content={textoModal}
            title={status}
          />
        </Box>
      </Box>
    </Content>
  )
}
