import React, { useState, useEffect } from 'react'
import Radio from '@material-ui/core/Radio'
import RadioGroup from '@material-ui/core/RadioGroup'
import Typography from '@material-ui/core/Typography'
import Chip from '@material-ui/core/Chip'
import FormControlLabel from '@material-ui/core/FormControlLabel'
import FormControl from '@material-ui/core/FormControl'
import { makeStyles } from '@material-ui/core/styles'
import Paper from '@material-ui/core/Paper'
import Grid from '@material-ui/core/Grid'
import Fab from '@material-ui/core/Fab'
import NavigateNextIcon from '@material-ui/icons/NavigateNext'
import NavigateBeforeIcon from '@material-ui/icons/NavigateBefore'
import SendIcon from '@material-ui/icons/Send'
import TextField from '@material-ui/core/TextField'

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1
  },
  rootGrid: {
    margin: 'auto'
  },
  paper: {
    padding: theme.spacing(2),
    textAlign: 'center',
    color: theme.palette.primary.main,
    BorderColor: theme.palette.primary.main,
    border: '2px solid',
    borderRadius: '20px'
  },
  questions: {
    transition: 'height 1s ease'
  },
  options: {
    width: '90%'
  },
  fab: {
    outline: 'none !important',
    marginRight: '0.5vh',
    marginLeft: '0.5vh'
  },
  counter: {
    height: '50px',
    width: '56px'
  },
  nav: {
    display: 'flex'
  },
  navButtons: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center'
  },
  submit: {
    display: 'flex',
    justifyContent: 'flex-end'
  },
  textField: {
    width: '95%',
    color: theme.palette.primary.main,
  }
}))

export default function (props) {
  const Questions = props.Questions
  const answerCallback = props.onAnswer
  const submitCallback = props.onSubmit

  const classes = useStyles()
  const [question, setQuestion] = useState(0)
  const [answers, setAnswers] = useState(new Array(Questions.length).fill(''))
  const [value, setValue] = React.useState('')
  const [sent, setSent] = useState(false)
  const [locked, setLocked] = useState(false)

  const onNext = () => {
    const newQuestion = question + 1
    if (question < Questions.length - 1) setQuestion(newQuestion)
    setValue(answers[newQuestion])
  }
  const onPrev = () => {
    const newQuestion = question - 1
    if (question > 0) setQuestion(newQuestion)
    setValue(answers[newQuestion])
  }

  const onSubmit = () => {
    if (submitCallback) submitCallback(answers)
  }

  const onAnswer = (event) => {
    const answer = event.target.value.toString()
    answers[question] = answer
    setValue(answer)
    setSent(false)
    if (answerCallback) answerCallback(question, answer)
  }

  useEffect(() => {
    if (props.Answers) {
      setAnswers(props.Answers)
      setValue(props.Answers[question])
    }
    if (props.sent) setSent(true)
    if (props.locked) setLocked(true)
  }, [props.Answers, props.sent])

  return (
    <div className={classes.root}>
      <Grid container className={classes.rootGrid} spacing={3} xs={12} md={8} lg={6}>
        <Grid item xs={12}>
          <Paper className={classes.paper}>
            <Typography variant='h5' component='h2' gutterBottom>
              {Questions[question].title}
            </Typography>
            <Typography variant='subtitle1' component='h2' gutterBottom>
              {Questions[question].description}
            </Typography>
          </Paper>
        </Grid>

        <Grid item xs={12} className={classes.questions}>
          <Paper className={classes.paper}>
            {Questions[question].type === 'text'
              ? <TextField
                className={classes.textField}
                id='outlined-multiline-static'
                label='Resposta'
                multiline
                rows={8}
                variant='outlined'
                onChange={onAnswer}
                value={value}
                disabled={locked}
              /> /* eslint-disable-line */
              : <FormControl component='fieldset' className={classes.options} disabled={locked}>
                <RadioGroup name='quiz' value={value} onChange={onAnswer}>
                  {Questions[question].options.map((option, index) => (
                    <FormControlLabel value={index.toString()} key={'opt' + question + '-' + index} control={<Radio />} label={option} />
                  ))}
                </RadioGroup>
              </FormControl>} {/* eslint-disable-line */}
          </Paper>
        </Grid>

        <Grid item xs={12}>
          <Paper className={classes.paper + ' ' + classes.nav}>
            <Grid item xs={0} sm={4} md={4} />
            <Grid item xs={8} sm={4} md={4} className={classes.navButtons}>
              <Fab aria-label='prev' disabled={question <= 0} className={classes.fab} color='primary' onClick={onPrev}>
                <NavigateBeforeIcon />
              </Fab>
              <Chip className={classes.counter} label={(question + 1) + '/' + Questions.length} variant='outlined' />
              <Fab aria-label='next' disabled={question >= Questions.length - 1} className={classes.fab} color='primary' onClick={onNext}>
                <NavigateNextIcon />
              </Fab>
            </Grid>
            <Grid item xs={4} className={classes.submit}>
              <Fab aria-label='submit' disabled={answers.includes('') || sent || locked} className={classes.fab} color='primary' onClick={onSubmit}>
                <SendIcon />
              </Fab>
            </Grid>
          </Paper>
        </Grid>
      </Grid>
    </div>
  )
}
