// API helper file
const request = require('ky')
const defaultURL = 'https://lti.saiteava.org/api'

const getURL = () => {
  const urlParams = new URLSearchParams(window.location.search)
  const url = urlParams.get('lti_url')
  return url
}

const getLtik = () => {
  const urlParams = new URLSearchParams(window.location.search)
  const ltik = urlParams.get('ltik')
  return ltik
}

const obj = {}

obj.getData = async (key) => {
  let data = JSON.parse(window.localStorage.getItem(key))
  const ltik = getLtik()
  // If ltik is found, make requests to server
  if (ltik) {
    try {
      const apiURL = getURL() || defaultURL
      const response = await request.get(apiURL + '/data?ltik=' + ltik + '&key=' + key, { mode: 'cors', credentials: 'include' }).json()
      if (response) data = response
    } catch (err) {
      console.log(err)
    }
  }
  return data
}

obj.setData = async (key, data) => {
  const obj = {
    data: data,
    key: key
  }
  window.localStorage.setItem(key, JSON.stringify(data))
  const ltik = getLtik()
  // If ltik is found, make requests to server
  if (ltik) {
    try {
      const apiURL = getURL() || defaultURL
      await request.post(apiURL + '/data?ltik=' + ltik, { json: obj, mode: 'cors', credentials: 'include' })
    } catch (err) {
      console.log(err)
    }
  }
  return true
}

// sendGrade returns false if can't submit grade.
obj.sendGrade = async () => {
  const ltik = getLtik()
  if (!ltik) return false
  try {
    const grade = {
      grade_rule: 'assert_done'
    }
    const apiURL = getURL() || defaultURL
    await request.post(apiURL + '/grade?ltik=' + ltik, { json: grade, mode: 'cors', credentials: 'include' })
  } catch (err) {
    return false
  }
}

export default obj
