import React, { useRef, useState } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Reference from "../../components/Reference";
import ShadedBox from "../../components/ShadedBox";
import { Content, StyledContainer } from "./styles";

export default function () {
  const headerref = useRef(Header);

  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }

    headerref.current.openRef(key);
  };

  const content = {
    text1: (
      <p>
        Um artigo médico publicado no início de abril de 2020 mostrou que, em Wuhan, na China, onde estava localizado o primeiro epicentro da doença no mundo, 36% das pessoas infectadas apresentavam sintomas como tonturas, dores de cabeça, convulsões, problemas de equilíbrio, dor neuropática e perda de olfato e paladar, isto é, o vírus afeta também o sistema nervoso central e periférico
        <Reference num='5' onClick={() => openRef(5)} />.
      </p>
    ),
    text2: (
      <p>
        Estudos subsequentes realizados em todo o mundo confirmaram essa observação e incluíram novos sintomas, como alterações de personalidade, catatonia, ansiedade, depressão, síndrome de fadiga crônica, estresse pós-traumático síndrome de Guillain-Barré, encefalite necrosante hemorrágica e meningoencefalite.
      </p>
    ),
    text3: (
      <p>
        Um artigo médico publicado no início de abril de 2020 mostrou que, em
        Wuhan, na China, onde estava localizado o primeiro epicentro do mundo,
        36% das pessoas infectadas apresentavam sintomas como tonturas, dores de
        cabeça, convulsões, problemas de equilíbrio, dor neuropática e perda de
        olfato e paladar, isto é, o vírus afeta também o sistema nervoso central
        e periférico
        <Reference num='5' onClick={() => openRef(5)} />.
      </p>
    ),
  };

  const [showContent, setShowContent] = useState(content.text1);
  const [currentContent, setCurrentContent] = useState(1);

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content currentContent={currentContent}>
          <Box className='title'>
            <Typography variant='h5'>
              Principais alterações pós-covid e estratégias de reabilitação
            </Typography>
          </Box>
          <Box className='content'>
            <Box className='text'>
              <Typography variant='body1' className=''>
                Inicialmente, as principais alterações provocadas pelo novo coronavírus estavam associadas a síndromes respiratórias, febre, dor de garganta, tosse e problemas intestinais. Com o passar do tempo, novas alterações foram surgindo e sendo estudadas e reportadas pelos profissionais da linha de frente, processo que continua acontecendo diariamente enquanto perdura a situação pandêmica.
                <br />
                <br />
              </Typography>
              <Box className='boxShaded'>
                <ShadedBox
                  Content='Após alguns períodos, o sistema neurológico alterado passou a ser uma manifestação evidente. Frequentemente, ouviam-se relatos sobre encefalite e encefalopatia, e as síndromes clínicas associadas com a covid-19 foram classificadas como um evento vascular, podendo ser hemorrágico, isquêmico agudo ou trombótico, envolvendo o parênquima cerebral. Nesse contexto, destacou-se a importância da colaboração interdisciplinar nas questões referentes à doença.'
                  backgroundColor='#4A81C2'
                  Color='#FFF'
                />
                <br />
                <br />
              </Box>
              <Typography variant='body1' className=''>
                <strong>Clique</strong> nos números abaixo para conhecer dados
                publicados em estudos.
                <br />
                <br />
              </Typography>
            </Box>
            <Box className='slide'>
              <Box className='numbers'>
                <Typography
                  variant='body1'
                  className=''
                  onClick={() => [
                    setShowContent(content.text1),
                    setCurrentContent(1),
                  ]}
                >
                  1
                </Typography>
                <Typography
                  variant='body1'
                  className=''
                  onClick={() => [
                    setShowContent(content.text2),
                    setCurrentContent(2),
                  ]}
                >
                  2
                </Typography>
                {/* <Typography
                  variant='body1'
                  className=''
                  onClick={() => [
                    setShowContent(content.text3),
                    setCurrentContent(3),
                  ]}
                >
                  3
                </Typography> */}
              </Box>
              <Typography variant='body1' className='contentSlide'>
                {showContent}
              </Typography>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer next='/p11' replay='/p9' />
    </StyledContainer>
  );
}
