import React, { useRef } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";
import SaberMais from "../../assets/buttons/saber.png";
import Attention from "../../components/Attention";
import ShadedBox from "../../components/ShadedBox";
import imagemA from "../../assets/images/p11A.png";
import imagemB from "../../assets/images/p11B.png";
import imagemC from "../../assets/images/p11C.png";
import imagemD from "../../assets/images/p11D.png";
import imagemE from "../../assets/images/p11E.png";
import imagem from "../../assets/images/p11.png";
import Simple from "../../components/Simple";

import { Content, StyledContainer } from "./styles";

export default function () {
  const headerref = useRef(Header);

  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }

    headerref.current.openRef(key);
  };

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content>
          <Box className='title'>
            <Typography variant='h5'>
              Principais alterações pós-covid e estratégias de reabilitação
            </Typography>
          </Box>
          <Box className='content'>
            <Box className='text'>
              <Typography variant='body1'>
                A reabilitação é um componente mister para a recuperação
                imediata após a doença, pois as principais intervenções de saúde
                são determinantes para avaliar a gravidade da disfunção
                observada entre os pacientes pós-covid-19.
                {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
              </Typography>
            </Box>
            <Box className='text-image'>
              <Box className='text-top-right'>
                <Typography variant='body1' className=''>
                  A reabilitação é importante para melhorar a função física e cognitiva e reduzir o risco de incapacidade. Uma equipe multidisciplinar é considerada de extrema importância no gerenciamento dos pacientes. As estratégias utilizadas variam de acordo com cada necessidade existente. Para conhecer os planejamentos, <strong>clique</strong> nas imagens ao lado.
                  {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
                </Typography>
              </Box>
              <Box className='image'>
                <img src={imagem} className='imagem-principal' />
                <Box className='button buttonA'>
                  <Dialog
                    content='Jogos e leitura de histórias. Após a finalização, o profissional e/ou familiar estimula o paciente a retornar e tentar elucidar o que foi realizado, estimulando a sua função cognitiva.'
                    title='Testes de memória'
                    p11
                    backgroundHover='transparent'
                    image={imagemA}
                  />
                </Box>
                <Box className='button buttonB'>
                  <Dialog
                    content='Utilização de quebra-cabeças, caça-palavras.'
                    title='Teste de Habilidades'
                    p11
                    backgroundHover='transparent'
                    image={imagemB}
                  />
                </Box>
                <Box className='button buttonC'>
                  <Dialog
                    content='Estímulo à escrita; exercícios como passar a bola no tempo de uma música.'
                    title='Estímulos sensoriais, motores e cognitivos'
                    p11
                    colorBackgroundHover='transparent'
                    image={imagemC}
                  />
                </Box>
                <Box className='button buttonD'>
                  <Dialog
                    content='Tem por objetivo fazer com que o paciente se lembre do maior número de séries, da forma mais precisa possível e, assim, preste atenção constantemente aos estímulos exibidos, que podem ser sensoriais e/ou visuais, na tela de um celular, computador ou tablet.'
                    title='Teste de concentração VISMEM-PLAN'
                    p11
                    backgroundHover='transparent'
                    image={imagemD}
                  />
                </Box>
                <Box className='button buttonE'>
                  <Dialog
                    content='Consiste em exercícios de rotações de tronco e coluna cervical que permitem melhorar a postura e evitar principalmente a hipertonia. Envolve a postura e a realização de movimentos que acontecem com um ponto de controle, como cabeça, ombros e pélvis, para realizar atividades que orientem o movimento de todo o corpo.'
                    title='Método Bobath'
                    p11
                    backgroundHover='transparent'
                    image={imagemE}
                  />
                </Box>
              </Box>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer replay='/p9' prev='/p10' />
    </StyledContainer>
  );
}
