import React, { useRef } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";
import SaberMais from "../../assets/buttons/saber.png";
import Attention from "../../components/Attention";
import ShadedBox from "../../components/ShadedBox";
import imagem from "../../assets/images/p13.png";
import Slide from "../../components/Slide";
import importante from '../../assets/images/importante.png'

import { Content, StyledContainer } from "./styles";

export default function () {
  const headerref = useRef(Header);

  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }

    headerref.current.openRef(key);
  };

  const material = [
    {
      text: "Recomendam-se terapias como a Cinesioterapia. Ela consiste em um conjunto de exercícios terapêuticos que ajudam a recuperar, fortalecer e alongar os músculos, minimizar os efeitos da inatividade, corrigir a ineficiência de músculos e, consequentemente, podem otimizar a saúde geral e prevenir alterações nos movimentos.",
    },
    {
      text: "Esses exercícios de Cinesioterapia podem ser motores, posturais, laborais e até mesmo respiratórios.",
    },
    {
      text: "A reabilitação nas condições pós-covid tem efeito satisfatório e benéfico quando o trabalho é realizado por uma equipe multiprofissional e sob uma lógica interdisciplinar. Quando devidamente assistidos nesse processo, os pacientes apresentam uma melhor recuperação e melhores resultados funcionais, incluindo ganho de força e melhora na função motora, resistência e equilíbrio.",
    },
  ];

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content>
          <Box className='title'>
            <Typography variant='h5'>
              Principais alterações musculoesqueléticas e motoras (mobilidade, força e equilíbrio) pós-covid e estratégias de reabilitação
            </Typography>
          </Box>
          <Box className='content'>
            <Box className='text-image'>
              <Box className='text'>
                <Typography variant='body1' className=''>
                  As alterações musculoesqueléticas estão relacionadas à perda ou redução da função, refletindo-se no metabolismo basal, na função renal, cardíaca e pulmonar, potencialmente promovendo o desenvolvimento de outras doenças como osteoporose, hipertensão, diabetes e obesidade.
                  <br />
                  <br />O declínio da resistência e o aumento da fraqueza podem ser atribuídos à disfunção e à atrofia muscular gerada pela imobilização prolongada a que pacientes graves são submetidos.
                  {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
                </Typography>
              </Box>
              <Box className='imagem'>
                <img src={imagem} />
              </Box>
            </Box>
            <Slide Content={material} />
            <Box className='dialog'>
              <Dialog
                content='Um estudo publicado na base de dados Pubmed Central evidenciou que pacientes em situação crítica estão suscetíveis a perder cerca de 17% ou até 30% da sua massa muscular somente nos dez primeiros dias de internação. Entender essas implicações e/ou complicações clínicas é uma forma de elaborar melhores estratégias de reabilitação desses pacientes.'
                title='IMPORTANTE'
                image={importante}
                colorBackgroundHover='transparent'
              />
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer replay='/p9' prev='/p12' />
    </StyledContainer>
  );
}
