import React, { useRef } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";
import SaberMais from "../../assets/buttons/saber.png";
import Attention from "../../components/Attention";
import ShadedBox from "../../components/ShadedBox";

import { Content, StyledContainer } from "./styles";

export default function () {
  const headerref = useRef(Header);

  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }

    headerref.current.openRef(key);
  };

  const text1 = 'As alterações auditivas podem ser permanentes ou não. O que vai definir isso é a gravidade com que essa parte foi atingida pelo vírus, causando inflamações ou danos permanentes, como também essa perda auditiva pode estar associada ao uso de medicação ototóxica.'
  const text2 = 'As investigações sobre essa relação foram iniciadas em 2020 e ainda estão sob análise e coleta de dados.'
  const text3 = 'O International Journal of Audiology publicou, em 22 de maio de 2021, uma avaliação que constata que a covid-19 pode não só piorar a audição, mas causar ou piorar a sensação de vertigem e zumbido no ouvido.'

  const [currentText, setText] = React.useState(text1)
  const [currentNumber, setNumber] = React.useState('01')
  const [class1, setClass1] = React.useState("marked")
  const [class2, setClass2] = React.useState("unmarked")
  const [class3, setClass3] = React.useState("unmarked")

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content>
          <Box className='title'>
            <Typography variant='h5'>
              Principais alterações sensoriais (auditivas, táteis, gustativas e olfativas) pós-covid e estratégias de reabilitação
            </Typography>
          </Box>
          <Box className='content'>
            <Box className='text'>
              <Typography variant='body1' className=''>
                Estudos recentes vêm sendo realizados intensivamente no atual
                cenário pandêmico, para compreender o que o vírus provoca no
                organismo. Entende-se que as sensações surgem pela interação de
                moléculas com os receptores da olfação, gustação, e tais
                impulsos se propagam para o sistema límbico e para as áreas
                corticais superiores
                <Reference num='10' onClick={() => openRef(10)} />.
                {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
              </Typography>
            </Box>

            <Box className='box-shadedBox'>
              <ShadedBox
                Content={
                  <p className='number-text'>
                    <Box className='number'>{currentNumber}</Box>
                    <Box className='reta' />
                    <p>
                      {currentText}
                    </p>
                  </p>
                }
                backgroundColor='#2764AD'
              />
              <Box className='index'>
                <div
                  className={class1}
                  onClick={() => {
                    setText(text1)
                    setNumber('01')
                    setClass1("marked")
                    setClass2("unmarked")
                    setClass3("unmarked")
                  }}
                >
                  1
                </div>
                <div
                  className={class2}
                  onClick={() => {
                    setText(text2)
                    setNumber('02')
                    setClass1("unmarked")
                    setClass2("marked")
                    setClass3("unmarked")
                  }}
                >
                  2
                </div>
                <div
                  className={class3}
                  onClick={() => {
                    setText(text3)
                    setNumber('03')
                    setClass1("unmarked")
                    setClass2("unmarked")
                    setClass3("marked")
                  }}
                >
                  3
                </div>
              </Box>
            </Box>
            <Box className='text text-bottom'>
              <Typography variant='body1' className=''>
                Recomendam-se estratégias de reabilitação sensoriais, como a realização tapping, que consiste em deslizar algum objeto, bolsa térmica e/ou gelo de modo a estimular calor e frio. Além disso, escovação e exercícios táteis com diferentes texturas auxiliam no retorno da sensibilidade.
                <br />
                <br />
                {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
              </Typography>
              <Typography variant='body1' className=''>
                Essas atividades diárias e repetidas despertam a função sensorial residual, e os programas de treinamento vão desde exercícios de estimulação até diferentes modalidades somatossensoriais.
                {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
              </Typography>
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer replay='/p9' prev='/p17' />
    </StyledContainer>
  );
}
