import React, { useRef } from "react";
import { Typography, Box } from "@material-ui/core";

import Header from "../../components/Header";
import Footer from "../../components/Footer";
import Reference from "../../components/Reference";
import Dialog from "../../components/Dialog";
import SaberMais from "../../assets/buttons/saber.png";
import Attention from "../../components/Attention";
import ShadedBox from "../../components/ShadedBox";
import imagemA from "../../assets/images/p6A.png";
import imagem from "../../assets/images/p8.png";
import Simple from "../../components/Simple";
import importante from "../../assets/images/importante.png";

import { Content, StyledContainer } from "./styles";

export default function () {
  const headerref = useRef(Header);

  const openRef = (key) => {
    if (!headerref.current) {
      return;
    }

    headerref.current.openRef(key);
  };

  return (
    <StyledContainer>
      <Header ref={headerref} />
      <Box className='container'>
        <Content>
          <Box className='title'>
            <Typography variant='h5'>
            Principais implicações e/ou complicações apresentadas por pacientes com condições pós-covid
            </Typography>
          </Box>
          <Box className='content'>
            <Box className='text'>
              <Typography variant='body1' className='subtitle'>
                Sistema renal
                {/* <p>
                  --- Exemplo de referência
                  <Reference num='1' onClick={() => openRef(1)} />. ---
                </p> */}
              </Typography>
            </Box>
            <Box className='text-image'>
              <Typography variant='body1' className=''>
                Os rins são constantemente acometidos por infecção, pois são parte integrante do sistema de metabolização de medicamentos. O agente causador da doença (SARS-CoV-2) tem uma estrutura de ligação ao receptor da Enzima de Conversão da Angiotensina 2 (ACE2), permitindo a entrada em células que expressam ACE2, como as células epiteliais alveolares pulmonares. Contudo estudos também indicam a possibilidade de lesão das células renais, uma vez que elas expressam altos níveis de ACE<Reference num='2' onClick={() => openRef(2)} />.
              </Typography>
              <Box className='image'>
                <img src={imagem} />
              </Box>
            </Box>
            <Box className='texts-down'>
              <Typography variant='body1' className='text-down'>
                Um estudo in vitro com células epiteliais tubulares proximais renais estabeleceu que o SARS-CoV manifestava infecção persistente e produtiva, que estava parcialmente correlacionada com a expressão da ACE2<Reference num='3' onClick={() => openRef(3)} />. Usando técnicas de célula única de última geração, Zou e colaboradores<Reference num='4' onClick={() => openRef(4)} />mostraram órgãos estratificados em alto e baixo risco, de acordo com o nível de expressão da ACE<Reference num='2' onClick={() => openRef(2)} />, indicando o rim como de alto risco.
              </Typography>
              <Typography variant='body1' className='text-down'>
                Esses achados indicam a possibilidade de infecção por SARS-CoV-2 em células renais. Consequentemente, elas tendem a perder parte de sua funcionalidade e, em casos de falência renal aguda grave, pode haver lesão desse órgão deixando cicatrizes renais, o que causa a redução crônica da função renal.
              </Typography>
            </Box>
            <Box className='Dialog'>
              <Dialog
                content='Todas essas complicações são só uma parte do que está sendo analisado diante da pandemia. O que precisa ser feito é o manejo específico de complicações e sequelas em conformidade com os protocolos nacionais vigentes.'
                title='IMPORTANTE'
                image={importante}
                colorBackgroundHover='rbga(0, 0, 0, 0)'
              />
            </Box>
          </Box>
        </Content>
      </Box>
      <Footer next='/p9' prev='/p7' />
    </StyledContainer>
  );
}
